.. _installation:

Installation
------------

PYPOWER depends upon:

* Python_ 2.5 or later and
* SciPy_ 0.7 or later.

It can be installed using setuptools_::

  $ easy_install PYPOWER

Alternatively, `download <http://pypi.python.org/pypi/PYPOWER#downloads>`_ and
unpack the tarball and install::

  $ tar zxf PYPOWER-4.0.tar.gz
  $ python setup.py install

On UNIX systems, use sudo for the latter command if you need to install the
scripts to a directory that requires root privileges::

  $ sudo python setup.py install

The development Git_ repository can be cloned from GitHub_::

  $ git clone http://github.com/rwl/PYPOWER.git

.. include:: ./link_names.txt
